    #include "ns3/core-module.h"
    #include "ns3/network-module.h"
    #include "ns3/netanim-module.h"
    #include "ns3/internet-module.h"
    #include "ns3/point-to-point-module.h"
    #include "ns3/applications-module.h"
    #include "ns3/point-to-point-layout-module.h"
    #include "ns3/mobility-helper.h"
    #include "ns3/mobility-model.h"
    #include "ns3/onoff-application.h"
    #include "ns3/ipv4-flow-classifier.h"
    // Network topology (default)
    //
    //        n2 n3 n4              .
    //         \ | /                . //n0----n5 
    //          \|/                 .
    //     n1--- n0 --n5            .
              
    //including header files for flow monitor
    #include "ns3/flow-monitor.h"
    #include "ns3/flow-monitor-helper.h"
    #include "ns3/traffic-control-module.h"
    #include "ns3/flow-monitor-module.h"
        
    using namespace ns3;  
    NS_LOG_COMPONENT_DEFINE ("Star");
    
    int 
    main (int argc, char *argv[])
    {
    
      //
      // Set up some default values for the simulation.
      //
      Config::SetDefault ("ns3::OnOffApplication::PacketSize", UintegerValue (137));
      
      // try and stick 15kb/s into the data rate
     Config::SetDefault ("ns3::OnOffApplication::DataRate", StringValue ("1400Kbps"));
    
      //
      // Default number of nodes in the star.  Overridable by command line argument.
      //
      uint32_t nSpokes = 5;
    
      CommandLine cmd;
      cmd.AddValue ("nSpokes", "Number of nodes to place in the star", nSpokes);
      cmd.Parse (argc, argv);
    
      NS_LOG_INFO ("Build star topology.");
      PointToPointHelper pointToPoint;
      pointToPoint.SetDeviceAttribute ("DataRate", StringValue ("5Mbps"));
      pointToPoint.SetChannelAttribute ("Delay", StringValue ("2ms"));
      PointToPointStarHelper star (nSpokes, pointToPoint);
    
      NS_LOG_INFO ("Install internet stack on all nodes.");
      InternetStackHelper internet;
      star.InstallStack (internet);
    
      NS_LOG_INFO ("Assign IP Addresses.");
      star.AssignIpv4Addresses (Ipv4AddressHelper ("10.1.1.0", "255.255.255.0"));
    
      NS_LOG_INFO ("Create applications.");
      //
      // Create a packet sink on the star "hub" to receive packets.
      // 
      uint16_t port = 50000;
      Address hubLocalAddress (InetSocketAddress (Ipv4Address::GetAny (), port));
      PacketSinkHelper packetSinkHelper ("ns3::TcpSocketFactory", hubLocalAddress);
      ApplicationContainer hubApp = packetSinkHelper.Install (star.GetHub ());
      hubApp.Start (Seconds (1.0));
      hubApp.Stop (Seconds (10.0));
    
      //
      // Create OnOff applications to send TCP to the hub, one on each spoke node.
      //
      OnOffHelper onOffHelper ("ns3::TcpSocketFactory", Address ());
      
      onOffHelper.SetAttribute ("OnTime", StringValue ("ns3::ConstantRandomVariable[Constant=1]"));
      onOffHelper.SetAttribute ("OffTime", StringValue ("ns3::ConstantRandomVariable[Constant=0]"));
    
      ApplicationContainer spokeApps;
    
      //creating TCP flow 
      NS_LOG_INFO ("TCP Flow");
      AddressValue remoteAddress (InetSocketAddress (star.GetHubIpv4Address (2), port));
      onOffHelper.SetAttribute ("Remote", remoteAddress);
      spokeApps.Add (onOffHelper.Install (star.GetSpokeNode (2)));
      
     spokeApps.Start (Seconds (1.0));
     spokeApps.Stop (Seconds (10.0));
 
    
    NS_LOG_INFO ("UDP Flow");
   
     OnOffHelper clientHelper("ns3::UdpSocketFactory", Address());
     clientHelper.SetAttribute ("OnTime", StringValue ("ns3::ConstantRandomVariable[Constant=1]"));
     clientHelper.SetAttribute ("OffTime", StringValue ("ns3::ConstantRandomVariable[Constant=0]"));
      ApplicationContainer clientApps;
      
      //creating UDP flow
      AddressValue remoteAddress1 (InetSocketAddress (star.GetHubIpv4Address (3), port));
      clientHelper.SetAttribute ("Remote", remoteAddress1);
      clientApps.Add (clientHelper.Install (star.GetSpokeNode (3)));
    
     clientApps.Start(Seconds(2.0));
     clientApps.Stop(Seconds(9.0));
    Simulator::Stop(Seconds(10.0));
     //flow monitor code
  Ptr<FlowMonitor> flowMonitor;
    FlowMonitorHelper flowHelper;
    flowMonitor= flowHelper.InstallAll();
     NS_LOG_INFO ("Run Simulation.");
     Simulator::Run();
    
    
    
    Ptr<Ipv4FlowClassifier> classifier=DynamicCast<Ipv4FlowClassifier> (flowHelper.GetClassifier());
    std::map<FlowId,FlowMonitor::FlowStats> stats=flowMonitor->GetFlowStats();
     

    for(std::map<FlowId,FlowMonitor::FlowStats>::const_iterator iter=stats.begin();iter!=stats.end();++iter)
    {
    Ipv4FlowClassifier::FiveTuple t =classifier->FindFlow(iter->first);
    NS_LOG_UNCOND("Flow ID: "<<iter->first<< " Source addr: "<< t.sourceAddress << " Dest Addr: "<<t.destinationAddress ); 
     uint32_t protocol = t.protocol;
    if (protocol == 6) {
        std::cout << "Type: TCP Flow" << std::endl;
    } else if (protocol == 17) {
        std::cout << "Type: UDP Flow" << std::endl;
    } 
    NS_LOG_UNCOND("Sent Packets = " <<iter->second.txPackets);
    NS_LOG_UNCOND("Received Packets = " <<iter->second.rxPackets);
    NS_LOG_UNCOND("Delay of current flow: " << iter->second.delaySum);
    NS_LOG_UNCOND("Throughput of current flow: " << iter->second.rxBytes*8.0/(iter->second.timeLastRxPacket.GetSeconds()-iter->second.timeFirstTxPacket.GetSeconds())/1024<<" Kbps");
     
    }
    
     Simulator::Destroy ();
     NS_LOG_INFO ("Done.");
 }
